<h1 align="center">Ntwine</h1>

### [+] Description :

***Upload pypi package using termux by Ntwine .***


### [+] Installation

##### Install primary dependency(python3)

  - ```pkg install python -y```

##### Install this tool

 - ```pip install Ntwine```

##### Run the tool

 - ```Ntwine```

#### Or, directly run
```
pip install Ntwine && Ntwine
```

### Features:
 
 - Easy to use.
 - Possible error diagnoser.
 - Portable file (Can be run from any directory).
 - If not found, all of the required packages will be installed on first run.


### Requirements

 - `Active Internet Connection`
 - `Python(3)`


#### Tested on

 - `Termux`


## Usage

1. Run the Tool.
2. Enter your Package details to be uploaded on pypi.
3. Done ! 


####  If this tool helped you, consider staring repository on github . Your stars encourage me a lot !!!

## GitHub Link :
  ```
https://github.com/CodingSangh/Ntwine
```

